###################
# Required Variables
###################

variable "cluster_config" {
  description = "The object containing the configuration to be used for terraforming an EKS cluster and other associated resources."
  type = object({
    # AWS region, the logical grouping for resources and the environment for the Terraforming
    region                          = string
    # The namespace value MUST match the name of an entry in the VPC's shared_clusters list
    namespace                       = string
    # The environment this cluster will be terraformed in
    env                             = string
    # ID of the VPC the EKS cluster will be created in
    vpc_id                          = string
    # CIDR block of the VPC the EKS cluster will be created in
    vpc_cidr_block                  = string
    # List of private subnet IDs used for creating nodes in
    private_subnets                 = list(string)
    # The name of the EKS cluster
    cluster_name                    = string
    # Kubernetes Cluster Version
    cluster_version                 = string
    # Enable Private API Server Access
    cluster_endpoint_private_access = optional(bool, true)
    # Enable Public API Server Access
    cluster_endpoint_public_access  = optional(bool, true)
    # Declare a list of Control Plane logs to create
    cluster_enabled_log_types       = optional(list(string), ["api", "audit", "authenticator"])
    # Create, update, and delete timeout configurations for the cluster
    cluster_timeouts                = optional(map(string), {})
    # Default Tags for Cluster Resources
    tags                            = optional(map(string), {})
    # Tags to apply for Internet-Facing AWS Load Balancers to use the public subnets
    public_subnet_tags              = optional(map(string), {})
    # Tags to apply for Internal-Facing AWS Load Balancers to use the private subnets
    private_subnet_tags             = optional(map(string), {})
    # Tagging the VPC that multiple cluster could be deployed in the same VPC
    vpc_tags                        = optional(map(string), {})
    # An Initial Managed Node Group Configuration
    managed_node_group              = object({
      name                   = optional(string, null)
      min_size               = optional(number, 3)
      desired_size           = optional(number, 3)
      max_size               = optional(number, 3)
      ami_type               = optional(string, "AL2_x86_64")
      instance_types         = optional(list(string), ["m6a.4xlarge", "m5a.4xlarge", "m6i.4xlarge", "m5.4xlarge"])
      vpc_security_group_ids = optional(list(string), [])
      capacity_type          = optional(string, "ON_DEMAND")
      volume_size            = optional(number, 50)
      volume_type            = optional(string, "gp3")
      iops                   = optional(number, 3000)
      throughput             = optional(number, 125)
    })
  })
}
