###################
# Locals
###################

locals {
  iam_role_name = var.node_role_name != null ? var.node_role_name : "${var.cluster_name}-eks-node-group"
  node_policies = merge(var.default_node_policies, var.additional_node_policies)
}

###################
# Create IAM Role for Nodes
###################

data "aws_partition" "current" {}

# Create IAM Node Role Trust Policy
data "aws_iam_policy_document" "assume_role_policy" {
  statement {
    sid     = "EKSNodeAssumeRole"
    actions = ["sts:AssumeRole"]

    principals {
      type        = "Service"
      identifiers = ["ec2.${data.aws_partition.current.dns_suffix}"]
    }
  }
}

# Create IAM Node Role
resource "aws_iam_role" "nodes" {

  name                  = local.iam_role_name
  description           = "IAM Role for EKS Nodes in the ${var.cluster_name} cluster"
  assume_role_policy    = data.aws_iam_policy_document.assume_role_policy.json
  force_detach_policies = true
  tags                  = var.tags
}

#  Attach all the node policies to the role
resource "aws_iam_role_policy_attachment" "this" {
  for_each = local.node_policies

  policy_arn = each.value
  role       = aws_iam_role.nodes.name
}
